# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dgt_sdk/protobuf/client_state.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from dgt_sdk.protobuf import client_list_control_pb2 as dgt__sdk_dot_protobuf_dot_client__list__control__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='dgt_sdk/protobuf/client_state.proto',
  package='',
  syntax='proto3',
  serialized_options=_b('\n\025sawtooth.sdk.protobufP\001Z\020client_state_pb2'),
  serialized_pb=_b('\n#dgt_sdk/protobuf/client_state.proto\x1a*dgt_sdk/protobuf/client_list_control.proto\"\x8a\x01\n\x16\x43lientStateListRequest\x12\x12\n\nstate_root\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\t\x12%\n\x06paging\x18\x04 \x01(\x0b\x32\x15.ClientPagingControls\x12$\n\x07sorting\x18\x05 \x03(\x0b\x32\x13.ClientSortControls\"\x91\x03\n\x17\x43lientStateListResponse\x12/\n\x06status\x18\x01 \x01(\x0e\x32\x1f.ClientStateListResponse.Status\x12/\n\x07\x65ntries\x18\x02 \x03(\x0b\x32\x1e.ClientStateListResponse.Entry\x12\x12\n\nstate_root\x18\x03 \x01(\t\x12%\n\x06paging\x18\x04 \x01(\x0b\x32\x15.ClientPagingResponse\x1a&\n\x05\x45ntry\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\"\xb0\x01\n\x06Status\x12\x10\n\x0cSTATUS_UNSET\x10\x00\x12\x06\n\x02OK\x10\x01\x12\x12\n\x0eINTERNAL_ERROR\x10\x02\x12\r\n\tNOT_READY\x10\x03\x12\x0b\n\x07NO_ROOT\x10\x04\x12\x0f\n\x0bNO_RESOURCE\x10\x05\x12\x12\n\x0eINVALID_PAGING\x10\x06\x12\x10\n\x0cINVALID_SORT\x10\x07\x12\x13\n\x0fINVALID_ADDRESS\x10\x08\x12\x10\n\x0cINVALID_ROOT\x10\t\"<\n\x15\x43lientStateGetRequest\x12\x12\n\nstate_root\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\t\"\xf8\x01\n\x16\x43lientStateGetResponse\x12.\n\x06status\x18\x01 \x01(\x0e\x32\x1e.ClientStateGetResponse.Status\x12\r\n\x05value\x18\x02 \x01(\x0c\x12\x12\n\nstate_root\x18\x03 \x01(\t\"\x8a\x01\n\x06Status\x12\x10\n\x0cSTATUS_UNSET\x10\x00\x12\x06\n\x02OK\x10\x01\x12\x12\n\x0eINTERNAL_ERROR\x10\x02\x12\r\n\tNOT_READY\x10\x03\x12\x0b\n\x07NO_ROOT\x10\x04\x12\x0f\n\x0bNO_RESOURCE\x10\x05\x12\x13\n\x0fINVALID_ADDRESS\x10\x06\x12\x10\n\x0cINVALID_ROOT\x10\x07\x42+\n\x15sawtooth.sdk.protobufP\x01Z\x10\x63lient_state_pb2b\x06proto3')
  ,
  dependencies=[dgt__sdk_dot_protobuf_dot_client__list__control__pb2.DESCRIPTOR,])



_CLIENTSTATELISTRESPONSE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='ClientStateListResponse.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OK', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTERNAL_ERROR', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_READY', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NO_ROOT', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NO_RESOURCE', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_PAGING', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_SORT', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_ADDRESS', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_ROOT', index=9, number=9,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=450,
  serialized_end=626,
)
_sym_db.RegisterEnumDescriptor(_CLIENTSTATELISTRESPONSE_STATUS)

_CLIENTSTATEGETRESPONSE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='ClientStateGetResponse.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OK', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTERNAL_ERROR', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_READY', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NO_ROOT', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NO_RESOURCE', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_ADDRESS', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_ROOT', index=7, number=7,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=801,
  serialized_end=939,
)
_sym_db.RegisterEnumDescriptor(_CLIENTSTATEGETRESPONSE_STATUS)


_CLIENTSTATELISTREQUEST = _descriptor.Descriptor(
  name='ClientStateListRequest',
  full_name='ClientStateListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state_root', full_name='ClientStateListRequest.state_root', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='address', full_name='ClientStateListRequest.address', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='paging', full_name='ClientStateListRequest.paging', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sorting', full_name='ClientStateListRequest.sorting', index=3,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=84,
  serialized_end=222,
)


_CLIENTSTATELISTRESPONSE_ENTRY = _descriptor.Descriptor(
  name='Entry',
  full_name='ClientStateListResponse.Entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='ClientStateListResponse.Entry.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='ClientStateListResponse.Entry.data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=409,
  serialized_end=447,
)

_CLIENTSTATELISTRESPONSE = _descriptor.Descriptor(
  name='ClientStateListResponse',
  full_name='ClientStateListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ClientStateListResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entries', full_name='ClientStateListResponse.entries', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state_root', full_name='ClientStateListResponse.state_root', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='paging', full_name='ClientStateListResponse.paging', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CLIENTSTATELISTRESPONSE_ENTRY, ],
  enum_types=[
    _CLIENTSTATELISTRESPONSE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=225,
  serialized_end=626,
)


_CLIENTSTATEGETREQUEST = _descriptor.Descriptor(
  name='ClientStateGetRequest',
  full_name='ClientStateGetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state_root', full_name='ClientStateGetRequest.state_root', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='address', full_name='ClientStateGetRequest.address', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=628,
  serialized_end=688,
)


_CLIENTSTATEGETRESPONSE = _descriptor.Descriptor(
  name='ClientStateGetResponse',
  full_name='ClientStateGetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ClientStateGetResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='ClientStateGetResponse.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state_root', full_name='ClientStateGetResponse.state_root', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CLIENTSTATEGETRESPONSE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=691,
  serialized_end=939,
)

_CLIENTSTATELISTREQUEST.fields_by_name['paging'].message_type = dgt__sdk_dot_protobuf_dot_client__list__control__pb2._CLIENTPAGINGCONTROLS
_CLIENTSTATELISTREQUEST.fields_by_name['sorting'].message_type = dgt__sdk_dot_protobuf_dot_client__list__control__pb2._CLIENTSORTCONTROLS
_CLIENTSTATELISTRESPONSE_ENTRY.containing_type = _CLIENTSTATELISTRESPONSE
_CLIENTSTATELISTRESPONSE.fields_by_name['status'].enum_type = _CLIENTSTATELISTRESPONSE_STATUS
_CLIENTSTATELISTRESPONSE.fields_by_name['entries'].message_type = _CLIENTSTATELISTRESPONSE_ENTRY
_CLIENTSTATELISTRESPONSE.fields_by_name['paging'].message_type = dgt__sdk_dot_protobuf_dot_client__list__control__pb2._CLIENTPAGINGRESPONSE
_CLIENTSTATELISTRESPONSE_STATUS.containing_type = _CLIENTSTATELISTRESPONSE
_CLIENTSTATEGETRESPONSE.fields_by_name['status'].enum_type = _CLIENTSTATEGETRESPONSE_STATUS
_CLIENTSTATEGETRESPONSE_STATUS.containing_type = _CLIENTSTATEGETRESPONSE
DESCRIPTOR.message_types_by_name['ClientStateListRequest'] = _CLIENTSTATELISTREQUEST
DESCRIPTOR.message_types_by_name['ClientStateListResponse'] = _CLIENTSTATELISTRESPONSE
DESCRIPTOR.message_types_by_name['ClientStateGetRequest'] = _CLIENTSTATEGETREQUEST
DESCRIPTOR.message_types_by_name['ClientStateGetResponse'] = _CLIENTSTATEGETRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ClientStateListRequest = _reflection.GeneratedProtocolMessageType('ClientStateListRequest', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTSTATELISTREQUEST,
  __module__ = 'dgt_sdk.protobuf.client_state_pb2'
  # @@protoc_insertion_point(class_scope:ClientStateListRequest)
  ))
_sym_db.RegisterMessage(ClientStateListRequest)

ClientStateListResponse = _reflection.GeneratedProtocolMessageType('ClientStateListResponse', (_message.Message,), dict(

  Entry = _reflection.GeneratedProtocolMessageType('Entry', (_message.Message,), dict(
    DESCRIPTOR = _CLIENTSTATELISTRESPONSE_ENTRY,
    __module__ = 'dgt_sdk.protobuf.client_state_pb2'
    # @@protoc_insertion_point(class_scope:ClientStateListResponse.Entry)
    ))
  ,
  DESCRIPTOR = _CLIENTSTATELISTRESPONSE,
  __module__ = 'dgt_sdk.protobuf.client_state_pb2'
  # @@protoc_insertion_point(class_scope:ClientStateListResponse)
  ))
_sym_db.RegisterMessage(ClientStateListResponse)
_sym_db.RegisterMessage(ClientStateListResponse.Entry)

ClientStateGetRequest = _reflection.GeneratedProtocolMessageType('ClientStateGetRequest', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTSTATEGETREQUEST,
  __module__ = 'dgt_sdk.protobuf.client_state_pb2'
  # @@protoc_insertion_point(class_scope:ClientStateGetRequest)
  ))
_sym_db.RegisterMessage(ClientStateGetRequest)

ClientStateGetResponse = _reflection.GeneratedProtocolMessageType('ClientStateGetResponse', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTSTATEGETRESPONSE,
  __module__ = 'dgt_sdk.protobuf.client_state_pb2'
  # @@protoc_insertion_point(class_scope:ClientStateGetResponse)
  ))
_sym_db.RegisterMessage(ClientStateGetResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dgt_sdk/protobuf/authorization.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='dgt_sdk/protobuf/authorization.proto',
  package='',
  syntax='proto3',
  serialized_options=_b('\n\025sawtooth.sdk.protobufP\001Z\021authorization_pb2'),
  serialized_pb=_b('\n$dgt_sdk/protobuf/authorization.proto\"6\n\x11\x43onnectionRequest\x12\x10\n\x08\x65ndpoint\x18\x01 \x01(\t\x12\x0f\n\x07network\x18\x02 \x01(\t\"\xca\x02\n\x12\x43onnectionResponse\x12,\n\x05roles\x18\x01 \x03(\x0b\x32\x1d.ConnectionResponse.RoleEntry\x12*\n\x06status\x18\x02 \x01(\x0e\x32\x1a.ConnectionResponse.Status\x1a^\n\tRoleEntry\x12\x17\n\x04role\x18\x01 \x01(\x0e\x32\t.RoleType\x12\x38\n\tauth_type\x18\x02 \x01(\x0e\x32%.ConnectionResponse.AuthorizationType\"-\n\x06Status\x12\x10\n\x0cSTATUS_UNSET\x10\x00\x12\x06\n\x02OK\x10\x01\x12\t\n\x05\x45RROR\x10\x02\"K\n\x11\x41uthorizationType\x12\x1c\n\x18\x41UTHORIZATION_TYPE_UNSET\x10\x00\x12\t\n\x05TRUST\x10\x01\x12\r\n\tCHALLENGE\x10\x02\"I\n\x19\x41uthorizationTrustRequest\x12\x18\n\x05roles\x18\x01 \x03(\x0e\x32\t.RoleType\x12\x12\n\npublic_key\x18\x02 \x01(\t\"6\n\x1a\x41uthorizationTrustResponse\x12\x18\n\x05roles\x18\x01 \x03(\x0e\x32\t.RoleType\"6\n\x16\x41uthorizationViolation\x12\x1c\n\tviolation\x18\x01 \x01(\x0e\x32\t.RoleType\"\x1f\n\x1d\x41uthorizationChallengeRequest\"1\n\x1e\x41uthorizationChallengeResponse\x12\x0f\n\x07payload\x18\x01 \x01(\x0c\"_\n\x1c\x41uthorizationChallengeSubmit\x12\x12\n\npublic_key\x18\x01 \x01(\t\x12\x11\n\tsignature\x18\x03 \x01(\t\x12\x18\n\x05roles\x18\x04 \x03(\x0e\x32\t.RoleType\"8\n\x1c\x41uthorizationChallengeResult\x12\x18\n\x05roles\x18\x01 \x03(\x0e\x32\t.RoleType*5\n\x08RoleType\x12\x13\n\x0fROLE_TYPE_UNSET\x10\x00\x12\x07\n\x03\x41LL\x10\x01\x12\x0b\n\x07NETWORK\x10\x02\x42,\n\x15sawtooth.sdk.protobufP\x01Z\x11\x61uthorization_pb2b\x06proto3')
)

_ROLETYPE = _descriptor.EnumDescriptor(
  name='RoleType',
  full_name='RoleType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ROLE_TYPE_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ALL', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NETWORK', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=855,
  serialized_end=908,
)
_sym_db.RegisterEnumDescriptor(_ROLETYPE)

RoleType = enum_type_wrapper.EnumTypeWrapper(_ROLETYPE)
ROLE_TYPE_UNSET = 0
ALL = 1
NETWORK = 2


_CONNECTIONRESPONSE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='ConnectionResponse.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OK', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=305,
  serialized_end=350,
)
_sym_db.RegisterEnumDescriptor(_CONNECTIONRESPONSE_STATUS)

_CONNECTIONRESPONSE_AUTHORIZATIONTYPE = _descriptor.EnumDescriptor(
  name='AuthorizationType',
  full_name='ConnectionResponse.AuthorizationType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AUTHORIZATION_TYPE_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRUST', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHALLENGE', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=352,
  serialized_end=427,
)
_sym_db.RegisterEnumDescriptor(_CONNECTIONRESPONSE_AUTHORIZATIONTYPE)


_CONNECTIONREQUEST = _descriptor.Descriptor(
  name='ConnectionRequest',
  full_name='ConnectionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='endpoint', full_name='ConnectionRequest.endpoint', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='network', full_name='ConnectionRequest.network', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=40,
  serialized_end=94,
)


_CONNECTIONRESPONSE_ROLEENTRY = _descriptor.Descriptor(
  name='RoleEntry',
  full_name='ConnectionResponse.RoleEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='role', full_name='ConnectionResponse.RoleEntry.role', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='auth_type', full_name='ConnectionResponse.RoleEntry.auth_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=209,
  serialized_end=303,
)

_CONNECTIONRESPONSE = _descriptor.Descriptor(
  name='ConnectionResponse',
  full_name='ConnectionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='roles', full_name='ConnectionResponse.roles', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='ConnectionResponse.status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CONNECTIONRESPONSE_ROLEENTRY, ],
  enum_types=[
    _CONNECTIONRESPONSE_STATUS,
    _CONNECTIONRESPONSE_AUTHORIZATIONTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=97,
  serialized_end=427,
)


_AUTHORIZATIONTRUSTREQUEST = _descriptor.Descriptor(
  name='AuthorizationTrustRequest',
  full_name='AuthorizationTrustRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='roles', full_name='AuthorizationTrustRequest.roles', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='public_key', full_name='AuthorizationTrustRequest.public_key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=429,
  serialized_end=502,
)


_AUTHORIZATIONTRUSTRESPONSE = _descriptor.Descriptor(
  name='AuthorizationTrustResponse',
  full_name='AuthorizationTrustResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='roles', full_name='AuthorizationTrustResponse.roles', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=504,
  serialized_end=558,
)


_AUTHORIZATIONVIOLATION = _descriptor.Descriptor(
  name='AuthorizationViolation',
  full_name='AuthorizationViolation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='violation', full_name='AuthorizationViolation.violation', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=560,
  serialized_end=614,
)


_AUTHORIZATIONCHALLENGEREQUEST = _descriptor.Descriptor(
  name='AuthorizationChallengeRequest',
  full_name='AuthorizationChallengeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=616,
  serialized_end=647,
)


_AUTHORIZATIONCHALLENGERESPONSE = _descriptor.Descriptor(
  name='AuthorizationChallengeResponse',
  full_name='AuthorizationChallengeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='payload', full_name='AuthorizationChallengeResponse.payload', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=649,
  serialized_end=698,
)


_AUTHORIZATIONCHALLENGESUBMIT = _descriptor.Descriptor(
  name='AuthorizationChallengeSubmit',
  full_name='AuthorizationChallengeSubmit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='public_key', full_name='AuthorizationChallengeSubmit.public_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signature', full_name='AuthorizationChallengeSubmit.signature', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='roles', full_name='AuthorizationChallengeSubmit.roles', index=2,
      number=4, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=700,
  serialized_end=795,
)


_AUTHORIZATIONCHALLENGERESULT = _descriptor.Descriptor(
  name='AuthorizationChallengeResult',
  full_name='AuthorizationChallengeResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='roles', full_name='AuthorizationChallengeResult.roles', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=797,
  serialized_end=853,
)

_CONNECTIONRESPONSE_ROLEENTRY.fields_by_name['role'].enum_type = _ROLETYPE
_CONNECTIONRESPONSE_ROLEENTRY.fields_by_name['auth_type'].enum_type = _CONNECTIONRESPONSE_AUTHORIZATIONTYPE
_CONNECTIONRESPONSE_ROLEENTRY.containing_type = _CONNECTIONRESPONSE
_CONNECTIONRESPONSE.fields_by_name['roles'].message_type = _CONNECTIONRESPONSE_ROLEENTRY
_CONNECTIONRESPONSE.fields_by_name['status'].enum_type = _CONNECTIONRESPONSE_STATUS
_CONNECTIONRESPONSE_STATUS.containing_type = _CONNECTIONRESPONSE
_CONNECTIONRESPONSE_AUTHORIZATIONTYPE.containing_type = _CONNECTIONRESPONSE
_AUTHORIZATIONTRUSTREQUEST.fields_by_name['roles'].enum_type = _ROLETYPE
_AUTHORIZATIONTRUSTRESPONSE.fields_by_name['roles'].enum_type = _ROLETYPE
_AUTHORIZATIONVIOLATION.fields_by_name['violation'].enum_type = _ROLETYPE
_AUTHORIZATIONCHALLENGESUBMIT.fields_by_name['roles'].enum_type = _ROLETYPE
_AUTHORIZATIONCHALLENGERESULT.fields_by_name['roles'].enum_type = _ROLETYPE
DESCRIPTOR.message_types_by_name['ConnectionRequest'] = _CONNECTIONREQUEST
DESCRIPTOR.message_types_by_name['ConnectionResponse'] = _CONNECTIONRESPONSE
DESCRIPTOR.message_types_by_name['AuthorizationTrustRequest'] = _AUTHORIZATIONTRUSTREQUEST
DESCRIPTOR.message_types_by_name['AuthorizationTrustResponse'] = _AUTHORIZATIONTRUSTRESPONSE
DESCRIPTOR.message_types_by_name['AuthorizationViolation'] = _AUTHORIZATIONVIOLATION
DESCRIPTOR.message_types_by_name['AuthorizationChallengeRequest'] = _AUTHORIZATIONCHALLENGEREQUEST
DESCRIPTOR.message_types_by_name['AuthorizationChallengeResponse'] = _AUTHORIZATIONCHALLENGERESPONSE
DESCRIPTOR.message_types_by_name['AuthorizationChallengeSubmit'] = _AUTHORIZATIONCHALLENGESUBMIT
DESCRIPTOR.message_types_by_name['AuthorizationChallengeResult'] = _AUTHORIZATIONCHALLENGERESULT
DESCRIPTOR.enum_types_by_name['RoleType'] = _ROLETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ConnectionRequest = _reflection.GeneratedProtocolMessageType('ConnectionRequest', (_message.Message,), dict(
  DESCRIPTOR = _CONNECTIONREQUEST,
  __module__ = 'dgt_sdk.protobuf.authorization_pb2'
  # @@protoc_insertion_point(class_scope:ConnectionRequest)
  ))
_sym_db.RegisterMessage(ConnectionRequest)

ConnectionResponse = _reflection.GeneratedProtocolMessageType('ConnectionResponse', (_message.Message,), dict(

  RoleEntry = _reflection.GeneratedProtocolMessageType('RoleEntry', (_message.Message,), dict(
    DESCRIPTOR = _CONNECTIONRESPONSE_ROLEENTRY,
    __module__ = 'dgt_sdk.protobuf.authorization_pb2'
    # @@protoc_insertion_point(class_scope:ConnectionResponse.RoleEntry)
    ))
  ,
  DESCRIPTOR = _CONNECTIONRESPONSE,
  __module__ = 'dgt_sdk.protobuf.authorization_pb2'
  # @@protoc_insertion_point(class_scope:ConnectionResponse)
  ))
_sym_db.RegisterMessage(ConnectionResponse)
_sym_db.RegisterMessage(ConnectionResponse.RoleEntry)

AuthorizationTrustRequest = _reflection.GeneratedProtocolMessageType('AuthorizationTrustRequest', (_message.Message,), dict(
  DESCRIPTOR = _AUTHORIZATIONTRUSTREQUEST,
  __module__ = 'dgt_sdk.protobuf.authorization_pb2'
  # @@protoc_insertion_point(class_scope:AuthorizationTrustRequest)
  ))
_sym_db.RegisterMessage(AuthorizationTrustRequest)

AuthorizationTrustResponse = _reflection.GeneratedProtocolMessageType('AuthorizationTrustResponse', (_message.Message,), dict(
  DESCRIPTOR = _AUTHORIZATIONTRUSTRESPONSE,
  __module__ = 'dgt_sdk.protobuf.authorization_pb2'
  # @@protoc_insertion_point(class_scope:AuthorizationTrustResponse)
  ))
_sym_db.RegisterMessage(AuthorizationTrustResponse)

AuthorizationViolation = _reflection.GeneratedProtocolMessageType('AuthorizationViolation', (_message.Message,), dict(
  DESCRIPTOR = _AUTHORIZATIONVIOLATION,
  __module__ = 'dgt_sdk.protobuf.authorization_pb2'
  # @@protoc_insertion_point(class_scope:AuthorizationViolation)
  ))
_sym_db.RegisterMessage(AuthorizationViolation)

AuthorizationChallengeRequest = _reflection.GeneratedProtocolMessageType('AuthorizationChallengeRequest', (_message.Message,), dict(
  DESCRIPTOR = _AUTHORIZATIONCHALLENGEREQUEST,
  __module__ = 'dgt_sdk.protobuf.authorization_pb2'
  # @@protoc_insertion_point(class_scope:AuthorizationChallengeRequest)
  ))
_sym_db.RegisterMessage(AuthorizationChallengeRequest)

AuthorizationChallengeResponse = _reflection.GeneratedProtocolMessageType('AuthorizationChallengeResponse', (_message.Message,), dict(
  DESCRIPTOR = _AUTHORIZATIONCHALLENGERESPONSE,
  __module__ = 'dgt_sdk.protobuf.authorization_pb2'
  # @@protoc_insertion_point(class_scope:AuthorizationChallengeResponse)
  ))
_sym_db.RegisterMessage(AuthorizationChallengeResponse)

AuthorizationChallengeSubmit = _reflection.GeneratedProtocolMessageType('AuthorizationChallengeSubmit', (_message.Message,), dict(
  DESCRIPTOR = _AUTHORIZATIONCHALLENGESUBMIT,
  __module__ = 'dgt_sdk.protobuf.authorization_pb2'
  # @@protoc_insertion_point(class_scope:AuthorizationChallengeSubmit)
  ))
_sym_db.RegisterMessage(AuthorizationChallengeSubmit)

AuthorizationChallengeResult = _reflection.GeneratedProtocolMessageType('AuthorizationChallengeResult', (_message.Message,), dict(
  DESCRIPTOR = _AUTHORIZATIONCHALLENGERESULT,
  __module__ = 'dgt_sdk.protobuf.authorization_pb2'
  # @@protoc_insertion_point(class_scope:AuthorizationChallengeResult)
  ))
_sym_db.RegisterMessage(AuthorizationChallengeResult)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
